@@ -21,23 +21,23 @@
 
 #ifndef MLT_VERSION_H
 #define MLT_VERSION_H
-
+#include "mlt_export.h"
 // Add quotes around any #define variables
 #define MLT_STRINGIZE2(s) #s
 #define MLT_STRINGIZE(s) MLT_STRINGIZE2(s)
 
 #define LIBMLT_VERSION_MAJOR 7
-#define LIBMLT_VERSION_MINOR 32
+#define LIBMLT_VERSION_MINOR 34
 #define LIBMLT_VERSION_REVISION 0
 #define LIBMLT_VERSION_INT \
     ((LIBMLT_VERSION_MAJOR << 16) + (LIBMLT_VERSION_MINOR << 8) + LIBMLT_VERSION_REVISION)
 #define LIBMLT_VERSION \
     MLT_STRINGIZE(LIBMLT_VERSION_MAJOR.LIBMLT_VERSION_MINOR.LIBMLT_VERSION_REVISION)
 
-extern int mlt_version_get_int();
-extern int mlt_version_get_major();
-extern int mlt_version_get_minor();
-extern int mlt_version_get_revision();
-extern char *mlt_version_get_string();
+MLT_EXPORT int mlt_version_get_int();
+MLT_EXPORT int mlt_version_get_major();
+MLT_EXPORT int mlt_version_get_minor();
+MLT_EXPORT int mlt_version_get_revision();
+MLT_EXPORT char *mlt_version_get_string();
 
 #endif
