@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2019-2023 Mattia Basaglia <dev@dragon.best>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 #include "animation_commands.hpp"
 
 #include "model/document.hpp"
@@ -288,6 +294,11 @@ QString glaxnimate::command::SetMultipleAnimated::auto_name(model::AnimatableBas
     return QObject::tr("Update %1").arg(prop->name());
 }
 
+bool glaxnimate::command::SetMultipleAnimated::empty() const
+{
+    return props.empty() && props_not_animated.empty();
+}
+
 glaxnimate::command::SetKeyframeTransition::SetKeyframeTransition(
         model::AnimatableBase* prop,
         int keyframe_index,
@@ -366,10 +377,11 @@ int glaxnimate::command::MoveKeyframe::redo_index() const
     return keyframe_index_after;
 }
 
-glaxnimate::command::RemoveAllKeyframes::RemoveAllKeyframes(model::AnimatableBase* prop, QVariant value)
+glaxnimate::command::RemoveAllKeyframes::RemoveAllKeyframes(model::AnimatableBase* prop, QVariant after)
     : QUndoCommand(QObject::tr("Remove animations from %1").arg(prop->name())),
       prop(prop),
-      value(std::move(value))
+      before(prop->value()),
+      after(std::move(after))
 {
     int count = prop->keyframe_count();
     keyframes.reserve(count);
@@ -387,7 +399,7 @@ glaxnimate::command::RemoveAllKeyframes::RemoveAllKeyframes(model::AnimatableBas
 void glaxnimate::command::RemoveAllKeyframes::redo()
 {
     prop->clear_keyframes();
-    prop->set_value(value);
+    prop->set_value(after);
 }
 
 void glaxnimate::command::RemoveAllKeyframes::undo()
@@ -397,6 +409,7 @@ void glaxnimate::command::RemoveAllKeyframes::undo()
         prop->set_keyframe(kf.time, kf.value, nullptr, true)->set_transition(kf.transition);
     }
     prop->set_time(prop->time());
+    prop->set_value(before);
 }
 
 
