@@ -2,6 +2,7 @@
  * kdenlivetitle_wrapper.cpp -- kdenlivetitle wrapper
  * Copyright (c) 2009 Marco Gittler <g.marco@freenet.de>
  * Copyright (c) 2009 Jean-Baptiste Mardelle <jb@kdenlive.org>
+ * Copyright (c) 2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -154,6 +155,7 @@ public:
         m_outline = outline;
         m_pen = QPen(outlineColor);
         m_pen.setWidthF(outline);
+        m_pen.setJoinStyle(Qt::RoundJoin);
         m_font = font;
         m_lineSpacing = lineSpacing + m_metrics.lineSpacing();
         m_align = align;
@@ -162,15 +164,11 @@ public:
         updateText(text);
     }
 
-    void updateText(QString text)
+    void updateText(const QString text)
     {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
         m_path.clear();
-#else
-        m_path = QPainterPath();
-#endif
         // Calculate line width
-        QStringList lines = text.split('\n');
+        const QStringList lines = text.split('\n');
         double linePos = m_metrics.ascent();
         foreach (const QString &line, lines) {
             QPainterPath linePath;
@@ -196,29 +194,28 @@ public:
             }
             linePos += m_lineSpacing;
             if (m_align == Qt::AlignHCenter) {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 11, 0))
                 double offset = (m_width - m_metrics.horizontalAdvance(line)) / 2;
-#else
-                double offset = (m_width - m_metrics.width(line)) / 2;
-#endif
                 linePath.translate(offset, 0);
             } else if (m_align == Qt::AlignRight) {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 11, 0))
                 double offset = (m_width - m_metrics.horizontalAdvance(line));
-#else
-                double offset = (m_width - m_metrics.width(line));
-#endif
                 linePath.translate(offset, 0);
             }
             m_path.addPath(linePath);
         }
         m_path.setFillRule(Qt::WindingFill);
+        if (!m_path.isEmpty()) {
+            int minWidth = m_path.boundingRect().width();
+            int minHeight = m_lineSpacing * lines.size();
+            if (m_boundingRect.width() < minWidth) {
+                m_boundingRect.setWidth(minWidth);
+            }
+            if (m_boundingRect.height() < minHeight) {
+                m_boundingRect.setHeight(minHeight);
+            }
+        }
     }
 
-    virtual QRectF boundingRect() const
-    {
-        return m_boundingRect;
-    }
+    virtual QRectF boundingRect() const { return m_boundingRect; }
 
     virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *w)
     {
@@ -248,19 +245,20 @@ public:
         int blurRadius = m_params.at(2).toInt();
         int offsetX = m_params.at(3).toInt();
         int offsetY = m_params.at(4).toInt();
-        m_shadow = QImage(m_boundingRect.width() + abs(offsetX) + 4 * blurRadius,
-                          m_boundingRect.height() + abs(offsetY) + 4 * blurRadius,
+        m_shadow = QImage(m_boundingRect.width() + abs(offsetX) + 4 * blurRadius + 2 * m_outline,
+                          m_boundingRect.height() + abs(offsetY) + 4 * blurRadius + 2 * m_outline,
                           QImage::Format_ARGB32_Premultiplied);
         m_shadow.fill(Qt::transparent);
         QPainterPath shadowPath = m_path;
-        offsetX -= 2 * blurRadius;
-        offsetY -= 2 * blurRadius;
+        offsetX -= (2 * blurRadius + m_outline + 1);
+        offsetY -= (2 * blurRadius + m_outline + 1);
         m_shadowOffset = QPoint(offsetX, offsetY);
-        shadowPath.translate(2 * blurRadius, 2 * blurRadius);
+        shadowPath.translate(2 * blurRadius + m_outline + 1, 2 * blurRadius + m_outline + 1);
         QPainter shadowPainter(&m_shadow);
         if (m_outline > 0) {
             QPainterPathStroker strokePath;
             strokePath.setWidth(m_outline);
+            strokePath.setJoinStyle(Qt::RoundJoin);
             QPainterPath stroke = strokePath.createStroke(shadowPath);
             shadowPath.addPath(stroke);
         }
@@ -288,7 +286,7 @@ private:
 
 QRectF stringToRect(const QString &s)
 {
-    QStringList l = s.split(',');
+    const QStringList l = s.split(',');
     if (l.size() < 4)
         return QRectF();
     return QRectF(l.at(0).toDouble(), l.at(1).toDouble(), l.at(2).toDouble(), l.at(3).toDouble())
@@ -297,7 +295,7 @@ QRectF stringToRect(const QString &s)
 
 QColor stringToColor(const QString &s)
 {
-    QStringList l = s.split(',');
+    const QStringList l = s.split(',');
     if (l.size() < 4)
         return QColor();
     return QColor(l.at(0).toInt(), l.at(1).toInt(), l.at(2).toInt(), l.at(3).toInt());
@@ -305,7 +303,7 @@ QColor stringToColor(const QString &s)
 }
 QTransform stringToTransform(const QString &s)
 {
-    QStringList l = s.split(',');
+    const QStringList l = s.split(',');
     if (l.size() < 9)
         return QTransform();
     return QTransform(l.at(0).toDouble(),
@@ -375,6 +373,7 @@ void loadFromXml(producer_ktitle self,
 
     QDomNode node;
     QDomNodeList items = title.elementsByTagName("item");
+    int itemId = 1;
     for (int i = 0; i < items.count(); i++) {
         QGraphicsItem *gitem = NULL;
         node = items.item(i);
@@ -453,11 +452,11 @@ void loadFromXml(producer_ktitle self,
                     QStringList values = gradientData.split(";");
                     if (values.count() < 5) {
                         // invalid gradient, use default
-                        values = QStringList() << "#ff0000"
-                                               << "#2e0046"
-                                               << "0"
-                                               << "100"
-                                               << "90";
+                        values = {QStringLiteral("#ff0000"),
+                                  QStringLiteral("#2e0046"),
+                                  QStringLiteral("0"),
+                                  QStringLiteral("100"),
+                                  QStringLiteral("90")};
                     }
                     QLinearGradient gr;
                     gr.setColorAt(values.at(2).toDouble() / 100, values.at(0));
@@ -491,20 +490,20 @@ void loadFromXml(producer_ktitle self,
                         txtProperties.namedItem("line-spacing").nodeValue().toInt(),
                         tabWidth);
                     if (txtProperties.namedItem("shadow").isNull() == false) {
-                        QStringList values = txtProperties.namedItem("shadow").nodeValue().split(
-                            ";");
+                        const QStringList values
+                            = txtProperties.namedItem("shadow").nodeValue().split(";");
                         txt->addShadow(values);
                     }
                     if (!txtProperties.namedItem("typewriter").isNull()) {
                         // typewriter effect
 
-                        QStringList values
+                        const QStringList values
                             = txtProperties.namedItem("typewriter").nodeValue().split(";");
                         int enabled = (static_cast<bool>(values.at(0).toInt()));
 
-                        if (enabled and values.count() >= 5) {
+                        if (enabled && values.count() >= 5) {
                             mlt_properties_set_int(producer_props, "_animated", 1);
-                            std::shared_ptr<TypeWriter> tw(new TypeWriter);
+                            std::shared_ptr<TypeWriter> tw(new TypeWriter());
                             tw->setFrameStep(values.at(1).toInt());
                             int macro = values.at(2).toInt();
                             tw->setStepSigma(values.at(3).toInt());
@@ -533,7 +532,10 @@ void loadFromXml(producer_ktitle self,
                             tw->setPattern(pattern.toStdString());
                             tw->parse();
                             tw->printParseResult();
-                            txt->setData(0, QVariant::fromValue<std::shared_ptr<TypeWriter>>(tw));
+                            scene->setProperty(QString::number(itemId).toLatin1(),
+                                               QVariant::fromValue<std::shared_ptr<TypeWriter>>(tw));
+                            txt->setData(0, itemId);
+                            itemId++;
                         } else {
                             txt->setData(0, QVariant());
                         }
@@ -567,9 +569,10 @@ void loadFromXml(producer_ktitle self,
                     if (!txtProperties.namedItem("typewriter").isNull()) {
                         // typewriter effect
                         mlt_properties_set_int(producer_props, "_animated", 1);
-                        QStringList effetData = QStringList()
-                                                << "typewriter" << text
-                                                << txtProperties.namedItem("typewriter").nodeValue();
+                        const QStringList effetData
+                            = {"typewriter",
+                               text,
+                               txtProperties.namedItem("typewriter").nodeValue()};
                         txt->setData(0, effetData);
                         if (!txtProperties.namedItem("textwidth").isNull())
                             txt->setData(1, txtProperties.namedItem("textwidth").nodeValue());
@@ -606,11 +609,11 @@ void loadFromXml(producer_ktitle self,
                     QStringList values = gradientData.split(";");
                     if (values.count() < 5) {
                         // invalid gradient, use default
-                        values = QStringList() << "#ff0000"
-                                               << "#2e0046"
-                                               << "0"
-                                               << "100"
-                                               << "90";
+                        values = {QStringLiteral("#ff0000"),
+                                  QStringLiteral("#2e0046"),
+                                  QStringLiteral("0"),
+                                  QStringLiteral("100"),
+                                  QStringLiteral("90")};
                     }
                     QLinearGradient gr;
                     gr.setColorAt(values.at(2).toDouble() / 100, values.at(0));
@@ -753,9 +756,18 @@ int initTitleProducer(mlt_producer producer)
     if (!createQApplicationIfNeeded(MLT_PRODUCER_SERVICE(producer))) {
         return false;
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (!QMetaType::type("QTextCursor")) {
         qRegisterMetaType<QTextCursor>("QTextCursor");
     }
+#else
+    if (!QMetaType::fromType<QTextCursor>().isRegistered()) {
+        qRegisterMetaType<QTextCursor>();
+    }
+    if (!QMetaType::fromType<std::shared_ptr<TypeWriter>>().isRegistered()) {
+        qRegisterMetaType<std::shared_ptr<TypeWriter>>();
+    }
+#endif
     return true;
 }
 
@@ -848,8 +860,9 @@ void drawKdenliveTitle(producer_ktitle self,
         for (int i = 0; i < items.count(); i++) {
             titem = dynamic_cast<PlainTextItem *>(items.at(i));
             if (titem && !titem->data(0).isNull()) {
-                std::shared_ptr<TypeWriter> ptr
-                    = titem->data(0).value<std::shared_ptr<TypeWriter>>();
+                int itemId = titem->data(0).toInt();
+                std::shared_ptr<TypeWriter> ptr = scene->property(QString::number(itemId).toLatin1())
+                                                      .value<std::shared_ptr<TypeWriter>>();
                 titem->updateText(ptr->render(position).c_str());
                 titem->updateShadows();
             }
@@ -857,13 +870,8 @@ void drawKdenliveTitle(producer_ktitle self,
 
         //must be extracted from kdenlive title
         self->rgba_image = (uint8_t *) mlt_pool_alloc(image_size);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
-        // QImage::Format_RGBA8888 was added in Qt5.2
         // Initialize the QImage with the MLT image because the data formats match.
         QImage img(self->rgba_image, width, height, QImage::Format_RGBA8888);
-#else
-        QImage img(width, height, QImage::Format_ARGB32);
-#endif
         img.fill(0);
         QPainter p1;
         p1.begin(&img);
@@ -920,7 +928,7 @@ void drawKdenliveTitle(producer_ktitle self,
         p1.end();
         self->format = mlt_image_rgba;
 
-        convert_qimage_to_mlt_rgba(&img, self->rgba_image, width, height);
+        convert_qimage_to_mlt(&img, self->rgba_image, width, height);
         self->current_image = (uint8_t *) mlt_pool_alloc(image_size);
         memcpy(self->current_image, self->rgba_image, image_size);
         mlt_properties_set_data(producer_props,
